

class IssueExists(Exception):
    pass


class IssueCreateError(Exception):
    pass


class TagError(Exception):
    pass


class TagNotFound(Exception):
    pass


class TagExistsError(Exception):
    pass
